@@ -6,9 +6,9 @@ Type annotations for dataexchange service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_dataexchange.literals import AssetType
+    from mypy_boto3_dataexchange.literals import AssetTypeType
 
-    data: AssetType = "S3_SNAPSHOT"
+    data: AssetTypeType = "S3_SNAPSHOT"
     ```
 """
 import sys
@@ -20,23 +20,23 @@ else:
 
 
 __all__ = (
-    "AssetType",
-    "Code",
-    "JobErrorLimitName",
-    "JobErrorResourceTypes",
+    "AssetTypeType",
+    "CodeType",
+    "JobErrorLimitNameType",
+    "JobErrorResourceTypesType",
     "ListDataSetRevisionsPaginatorName",
     "ListDataSetsPaginatorName",
     "ListJobsPaginatorName",
     "ListRevisionAssetsPaginatorName",
-    "Origin",
-    "ServerSideEncryptionTypes",
-    "State",
+    "OriginType",
+    "ServerSideEncryptionTypesType",
+    "StateType",
     "TypeType",
 )
 
 
-AssetType = Literal["S3_SNAPSHOT"]
-Code = Literal[
+AssetTypeType = Literal["S3_SNAPSHOT"]
+CodeType = Literal[
     "ACCESS_DENIED_EXCEPTION",
     "INTERNAL_SERVER_EXCEPTION",
     "MALWARE_DETECTED",
@@ -45,15 +45,15 @@ Code = Literal[
     "SERVICE_QUOTA_EXCEEDED_EXCEPTION",
     "VALIDATION_EXCEPTION",
 ]
-JobErrorLimitName = Literal["Asset size in GB", "Assets per revision"]
-JobErrorResourceTypes = Literal["ASSET", "REVISION"]
+JobErrorLimitNameType = Literal["Asset size in GB", "Assets per revision"]
+JobErrorResourceTypesType = Literal["ASSET", "REVISION"]
 ListDataSetRevisionsPaginatorName = Literal["list_data_set_revisions"]
 ListDataSetsPaginatorName = Literal["list_data_sets"]
 ListJobsPaginatorName = Literal["list_jobs"]
 ListRevisionAssetsPaginatorName = Literal["list_revision_assets"]
-Origin = Literal["ENTITLED", "OWNED"]
-ServerSideEncryptionTypes = Literal["AES256", "aws:kms"]
-State = Literal["CANCELLED", "COMPLETED", "ERROR", "IN_PROGRESS", "TIMED_OUT", "WAITING"]
+OriginType = Literal["ENTITLED", "OWNED"]
+ServerSideEncryptionTypesType = Literal["AES256", "aws:kms"]
+StateType = Literal["CANCELLED", "COMPLETED", "ERROR", "IN_PROGRESS", "TIMED_OUT", "WAITING"]
 TypeType = Literal[
     "EXPORT_ASSETS_TO_S3",
     "EXPORT_ASSET_TO_SIGNED_URL",
